@@ -93,6 +93,8 @@ extern "C" {
 #define NL_CHOMP    40
 #define NL_KEEP     50
 
+#define EMITTER_MARK_NODE_FLAG_PERMIT_DUPLICATE_NODES 1
+
 /*
  * Node definitions
  */
@@ -349,6 +351,8 @@ struct _syck_emitter {
     SyckLevel *levels;
     int lvl_idx;
     int lvl_capa;
+    int max_depth;
+    int depth;
     /* Pointer for extension's use */
     void *bonus;
 };
@@ -392,7 +396,7 @@ long syck_io_str_read( char *, SyckIoStr *, long, long );
 char *syck_base64enc( char *, long );
 char *syck_base64dec( char *, long, long * );
 SyckEmitter *syck_new_emitter( void );
-SYMID syck_emitter_mark_node( SyckEmitter *, st_data_t );
+SYMID syck_emitter_mark_node( SyckEmitter *, st_data_t, int );
 void syck_emitter_ignore_id( SyckEmitter *, SYMID );
 void syck_output_handler( SyckEmitter *, SyckOutputHandler );
 void syck_emitter_handler( SyckEmitter *, SyckEmitterHandler );
